@@ -88,6 +88,12 @@ typedef struct {
   GtkWidget *param_account_widget;
   GtkWidget *param_password_widget;
 
+  gboolean automatic_change;
+  GtkWidget *remember_password_widget;
+
+  /* Used only for IRC accounts */
+  EmpathyIrcNetworkChooser *irc_network_chooser;
+
   gboolean dispose_run;
 } EmpathyAccountWidgetPriv;
 
@@ -106,6 +112,8 @@ enum {
   LAST_SIGNAL
 };
 
+static void account_widget_apply_and_log_in (EmpathyAccountWidget *);
+
 static guint signals[LAST_SIGNAL] = { 0 };
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyAccountWidget)
@@ -181,6 +189,11 @@ static void
 account_widget_entry_changed_cb (GtkEditable *entry,
     EmpathyAccountWidget *self)
 {
+  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+
+  if (priv->automatic_change)
+    return;
+
   account_widget_entry_changed_common (self, GTK_ENTRY (entry), FALSE);
   empathy_account_widget_changed (self);
 }
@@ -354,6 +367,16 @@ password_entry_changed_cb (GtkEditable *entry,
       GTK_ENTRY_ICON_SECONDARY, !EMP_STR_EMPTY (str));
 }
 
+static void
+password_entry_activated_cb (GtkEntry *entry,
+    EmpathyAccountWidget *self)
+{
+    EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+
+    if (gtk_widget_get_sensitive (priv->apply_button))
+        account_widget_apply_and_log_in (self);
+}
+
 void
 empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
     GtkWidget *widget,
@@ -430,6 +453,8 @@ empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
               G_CALLBACK (clear_icon_released_cb), self);
           g_signal_connect (widget, "changed",
               G_CALLBACK (password_entry_changed_cb), self);
+          g_signal_connect (widget, "activate",
+              G_CALLBACK (password_entry_activated_cb), self);
         }
 
       g_signal_connect (widget, "changed",
@@ -488,11 +513,34 @@ empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
     }
 }
 
+static GHashTable *
+build_translated_params (void)
+{
+  GHashTable *hash;
+
+  hash = g_hash_table_new (g_str_hash, g_str_equal);
+  g_hash_table_insert (hash, "account", _("Account"));
+  g_hash_table_insert (hash, "password", _("Password"));
+  g_hash_table_insert (hash, "server", _("Server"));
+  g_hash_table_insert (hash, "port", _("Port"));
+
+  return hash;
+}
+
 static gchar *
 account_widget_generic_format_param_name (const gchar *param_name)
 {
   gchar *str;
   gchar *p;
+  static GHashTable *translated_params = NULL;
+
+  if (G_UNLIKELY (translated_params == NULL))
+    translated_params = build_translated_params ();
+
+  /* Translate most common parameters */
+  str = g_hash_table_lookup (translated_params, param_name);
+  if (str != NULL)
+    return g_strdup (str);
 
   str = g_strdup (param_name);
 
@@ -600,6 +648,7 @@ accounts_widget_generic_setup (EmpathyAccountWidget *self,
             case 't': minint = 0;          maxint = G_MAXUINT64; break;
             case 'd': minint = G_MININT32; maxint = G_MAXINT32;
               step = 0.1; break;
+            default: g_assert_not_reached ();
             }
 
           str = g_strdup_printf (_("%s:"), param_name_formatted);
@@ -775,8 +824,7 @@ account_widget_applied_cb (GObject *source_object,
 }
 
 static void
-account_widget_apply_clicked_cb (GtkWidget *button,
-    EmpathyAccountWidget *self)
+account_widget_apply_and_log_in (EmpathyAccountWidget *self)
 {
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
   gboolean display_name_overridden;
@@ -813,6 +861,13 @@ account_widget_apply_clicked_cb (GtkWidget *button,
       account_widget_applied_cb, self);
 }
 
+static void
+account_widget_apply_clicked_cb (GtkWidget *button,
+    EmpathyAccountWidget *self)
+{
+    account_widget_apply_and_log_in (self);
+}
+
 static void
 account_widget_setup_generic (EmpathyAccountWidget *self)
 {
@@ -900,8 +955,17 @@ account_widget_build_irc (EmpathyAccountWidget *self,
   const char *filename)
 {
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
-  empathy_account_widget_irc_build (self, filename,
-    &priv->table_common_settings);
+
+  if (priv->simple)
+    {
+      priv->irc_network_chooser = empathy_account_widget_irc_build_simple (self,
+          filename);
+    }
+  else
+    {
+      priv->irc_network_chooser = empathy_account_widget_irc_build (self,
+          filename, &priv->table_common_settings);
+    }
 }
 
 static void
@@ -911,6 +975,17 @@ account_widget_build_sip (EmpathyAccountWidget *self,
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
   empathy_account_widget_sip_build (self, filename,
     &priv->table_common_settings);
+
+  if (priv->simple)
+    {
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password_simple"));
+    }
+  else
+    {
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password"));
+    }
 }
 
 static void
@@ -931,6 +1006,9 @@ account_widget_build_msn (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_simple");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -947,6 +1025,9 @@ account_widget_build_msn (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1073,6 +1154,9 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_simple");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password_simple"));
     }
   else if (priv->simple && is_gtalk)
     {
@@ -1087,6 +1171,9 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_g_simple");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password_g_simple"));
     }
   else if (priv->simple && is_facebook)
     {
@@ -1103,6 +1190,9 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
       setup_facebook_id_widget (self, entry_id);
 
       self->ui_details->default_focus = g_strdup ("entry_id_fb_simple");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password_fb_simple"));
     }
   else
     {
@@ -1147,6 +1237,9 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
       self->ui_details->default_focus = g_strdup ("entry_id");
       priv->spinbutton_port = spinbutton_port;
 
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password"));
+
       g_signal_connect (checkbutton_ssl, "toggled",
           G_CALLBACK (account_widget_jabber_ssl_toggled_cb),
           self);
@@ -1184,6 +1277,9 @@ account_widget_build_icq (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_uin_simple");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -1202,6 +1298,9 @@ account_widget_build_icq (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_uin");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1224,6 +1323,9 @@ account_widget_build_aim (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_screenname_simple");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -1241,6 +1343,9 @@ account_widget_build_aim (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_screenname");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1262,6 +1367,9 @@ account_widget_build_yahoo (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_simple");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -1273,15 +1381,16 @@ account_widget_build_yahoo (EmpathyAccountWidget *self,
       empathy_account_widget_handle_params (self,
           "entry_id", "account",
           "entry_password", "password",
-          "entry_server", "server",
           "entry_locale", "room-list-locale",
           "entry_charset", "charset",
           "spinbutton_port", "port",
-          "checkbutton_yahoojp", "yahoojp",
           "checkbutton_ignore_invites", "ignore-invites",
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1303,6 +1412,9 @@ account_widget_build_groupwise (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id_simple");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password_simple"));
     }
   else
     {
@@ -1319,6 +1431,9 @@ account_widget_build_groupwise (EmpathyAccountWidget *self,
           NULL);
 
       self->ui_details->default_focus = g_strdup ("entry_id");
+
+      priv->remember_password_widget = GTK_WIDGET (gtk_builder_get_object (
+              self->ui_details->gui, "remember_password"));
     }
 }
 
@@ -1453,6 +1568,23 @@ do_get_property (GObject *object,
     }
 }
 
+static void
+set_apply_button (EmpathyAccountWidget *self)
+{
+  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+  GtkWidget *image;
+
+  /* We can't use the stock button as its accelerator ('A') clashes with the
+   * Add button. */
+  gtk_button_set_use_stock (GTK_BUTTON (priv->apply_button), FALSE);
+
+  gtk_button_set_label (GTK_BUTTON (priv->apply_button), _("A_pply"));
+  gtk_button_set_use_underline (GTK_BUTTON (priv->apply_button), TRUE);
+
+  image = gtk_image_new_from_stock (GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image (GTK_BUTTON (priv->apply_button), image);
+}
+
 static void
 presence_changed_cb (TpAccountManager *manager,
     TpConnectionPresenceType state,
@@ -1486,9 +1618,7 @@ presence_changed_cb (TpAccountManager *manager,
     {
       /* We are offline or modifying an existing account, display
        * a Save button */
-      gtk_button_set_image (GTK_BUTTON (priv->apply_button), NULL);
-      gtk_button_set_use_stock (GTK_BUTTON (priv->apply_button), TRUE);
-      gtk_button_set_label (GTK_BUTTON (priv->apply_button), GTK_STOCK_APPLY);
+      set_apply_button (self);
     }
 }
 
@@ -1555,7 +1685,7 @@ add_enable_checkbox (EmpathyAccountWidget *self,
   gtk_widget_show (w);
 #else
   priv->enabled_checkbox =
-      gtk_check_button_new_with_label (_("Enabled"));
+      gtk_check_button_new_with_mnemonic (_("_Enabled"));
 
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->enabled_checkbox),
       is_enabled);
@@ -1634,6 +1764,48 @@ add_register_buttons (EmpathyAccountWidget *self,
 }
 #endif /* HAVE_MEEGO */
 
+static void
+remember_password_toggled_cb (GtkToggleButton *button,
+    EmpathyAccountWidget *self)
+{
+  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+
+  if (gtk_toggle_button_get_active (button))
+    {
+      gtk_widget_set_sensitive (priv->param_password_widget, TRUE);
+    }
+  else
+    {
+      gtk_widget_set_sensitive (priv->param_password_widget, FALSE);
+      gtk_entry_set_text (GTK_ENTRY (priv->param_password_widget), "");
+      empathy_account_settings_unset (priv->settings, "password");
+    }
+}
+
+static void
+account_settings_password_retrieved_cb (GObject *object,
+    gpointer user_data)
+{
+  EmpathyAccountWidget *self = user_data;
+  EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+  const gchar *password = empathy_account_settings_get_string (
+      priv->settings, "password");
+
+  if (password != NULL)
+    {
+      /* We have to do this so that when we call gtk_entry_set_text,
+       * the ::changed callback doesn't think the user made the
+       * change. */
+      priv->automatic_change = TRUE;
+      gtk_entry_set_text (GTK_ENTRY (priv->param_password_widget), password);
+      priv->automatic_change = FALSE;
+    }
+
+  gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (priv->remember_password_widget),
+      !EMP_STR_EMPTY (password));
+}
+
 static void
 do_constructed (GObject *obj)
 {
@@ -1700,6 +1872,42 @@ do_constructed (GObject *obj)
           NULL);
     }
 
+  /* remember password */
+  if (priv->param_password_widget != NULL
+      && priv->remember_password_widget != NULL
+      && empathy_account_settings_supports_sasl (priv->settings))
+    {
+      if (priv->simple)
+        {
+          gtk_toggle_button_set_active (
+              GTK_TOGGLE_BUTTON (priv->remember_password_widget), TRUE);
+        }
+      else
+        {
+          gtk_toggle_button_set_active (
+              GTK_TOGGLE_BUTTON (priv->remember_password_widget),
+              !EMP_STR_EMPTY (empathy_account_settings_get_string (
+                      priv->settings, "password")));
+
+          /* The password might not have been retrieved from the
+           * keyring yet. We should update the remember password
+           * toggle button and the password entry when/if it is. */
+          g_signal_connect (priv->settings, "password-retrieved",
+              G_CALLBACK (account_settings_password_retrieved_cb), self);
+        }
+
+      g_signal_connect (priv->remember_password_widget, "toggled",
+          G_CALLBACK (remember_password_toggled_cb), self);
+
+      remember_password_toggled_cb (
+          GTK_TOGGLE_BUTTON (priv->remember_password_widget), self);
+    }
+  else if (priv->remember_password_widget != NULL
+      && !empathy_account_settings_supports_sasl (priv->settings))
+    {
+      gtk_widget_set_visible (priv->remember_password_widget, FALSE);
+    }
+
   /* dup and init the account-manager */
   priv->account_manager = tp_account_manager_dup ();
 
@@ -1711,10 +1919,19 @@ do_constructed (GObject *obj)
   if (!priv->simple)
     {
       GtkWidget *hbox = gtk_hbox_new (TRUE, 3);
+      GtkWidget *image;
 
-      priv->cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+      /*  We can't use the stock button as its accelerator ('C') clashes with
+       *  the Close button. */
+      priv->cancel_button = gtk_button_new ();
+      gtk_button_set_label (GTK_BUTTON (priv->cancel_button), _("Ca_ncel"));
+      gtk_button_set_use_underline (GTK_BUTTON (priv->cancel_button), TRUE);
 
-      priv->apply_button = gtk_button_new_from_stock (GTK_STOCK_APPLY);
+      image = gtk_image_new_from_stock (GTK_STOCK_CANCEL, GTK_ICON_SIZE_BUTTON);
+      gtk_button_set_image (GTK_BUTTON (priv->cancel_button), image);
+
+      priv->apply_button = gtk_button_new ();
+      set_apply_button (self);
 
       /* We'll change this button to a "Log in" one if we are creating a new
        * account and are connected. */
@@ -1772,7 +1989,8 @@ do_constructed (GObject *obj)
   display_name = empathy_account_settings_get_display_name (priv->settings);
   default_display_name = empathy_account_widget_get_default_display_name (self);
 
-  if (tp_strdiff (display_name, default_display_name))
+  if (tp_strdiff (display_name, default_display_name) &&
+      !priv->creating_account)
     {
       /* The display name of the account is not the one that we'd assign by
        * default; assume that the user changed it manually */
@@ -1983,17 +2201,19 @@ empathy_account_widget_get_default_display_name (EmpathyAccountWidget *self)
       /* TODO: this should be done in empathy-account-widget-irc */
       if (!tp_strdiff (protocol, "irc"))
         {
-          const gchar* server;
-          server = empathy_account_settings_get_string (priv->settings,
-              "server");
+          EmpathyIrcNetwork *network;
+
+          network = empathy_irc_network_chooser_get_network (
+              priv->irc_network_chooser);
+          g_assert (network != NULL);
 
           /* To translators: The first parameter is the login id and the
-           * second one is the server. The resulting string will be something
-           * like: "MyUserName on chat.freenode.net".
+           * second one is the network. The resulting string will be something
+           * like: "MyUserName on freenode".
            * You should reverse the order of these arguments if the
            * server should come before the login id in your locale.*/
           default_display_name = g_strdup_printf (_("%1$s on %2$s"),
-              login_id, server);
+              login_id, empathy_irc_network_get_name (network));
         }
       else if (account_widget_is_facebook (self))
         {
