@@ -102,10 +102,7 @@ static void     log_window_chats_populate                  (EmpathyLogWindow *wi
 static void     log_window_chats_setup                     (EmpathyLogWindow *window);
 static void     log_window_chats_accounts_changed_cb       (GtkWidget        *combobox,
 							    EmpathyLogWindow *window);
-static void     log_window_chats_set_selected              (EmpathyLogWindow *window,
-							    TpAccount        *account,
-							    const gchar      *chat_id,
-							    gboolean          is_chatroom);
+static void     log_window_chats_set_selected              (EmpathyLogWindow *window);
 static gboolean log_window_chats_get_selected              (EmpathyLogWindow *window,
 							    TpAccount       **account,
 							    gchar           **chat_id,
@@ -182,8 +179,35 @@ account_chooser_ready_cb (EmpathyAccountChooser *chooser,
 			EmpathyLogWindow *window)
 {
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (window->notebook), 1);
-	log_window_chats_set_selected (window, window->selected_account,
-				       window->selected_chat_id, window->selected_is_chatroom);
+
+	/* We'll display the account once the model has been populate with the chats
+	 * of this account. */
+	empathy_account_chooser_set_account (EMPATHY_ACCOUNT_CHOOSER (
+		window->account_chooser_chats), window->selected_account);
+}
+
+static void
+select_account_once_ready (EmpathyLogWindow *self,
+			   TpAccount *account,
+			   const gchar *chat_id,
+			   gboolean is_chatroom)
+{
+	EmpathyAccountChooser *account_chooser = EMPATHY_ACCOUNT_CHOOSER (self->account_chooser_chats);
+
+	tp_clear_object (&self->selected_account);
+	self->selected_account = g_object_ref (account);
+
+	g_free (self->selected_chat_id);
+	self->selected_chat_id = g_strdup (chat_id);
+
+	self->selected_is_chatroom = is_chatroom;
+
+	if (empathy_account_chooser_is_ready (account_chooser))
+		account_chooser_ready_cb (account_chooser, self);
+	else
+		/* Chat will be selected once the account chooser is ready */
+		g_signal_connect (account_chooser, "ready",
+				  G_CALLBACK (account_chooser_ready_cb), self);
 }
 
 GtkWidget *
@@ -198,13 +222,12 @@ empathy_log_window_show (TpAccount  *account,
 	gchar                  *filename;
 	EmpathyLogWindow       *window;
 
-	if (log_window) {
+	if (log_window != NULL) {
 		gtk_window_present (GTK_WINDOW (log_window->window));
 
-		if (account && chat_id) {
+		if (account != NULL && chat_id != NULL) {
 			gtk_notebook_set_current_page (GTK_NOTEBOOK (log_window->notebook), 1);
-			log_window_chats_set_selected (log_window, account,
-						       chat_id, is_chatroom);
+			select_account_once_ready (log_window, account, chat_id, is_chatroom);
 		}
 
 		return log_window->window;
@@ -295,20 +318,10 @@ empathy_log_window_show (TpAccount  *account,
 	log_window_chats_setup (window);
 	log_window_chats_populate (window);
 
-	if (account && chat_id) {
-		window->selected_account = account;
-		window->selected_chat_id = g_strdup (chat_id);
-		window->selected_is_chatroom = is_chatroom;
+	if (account != NULL && chat_id != NULL)
+		select_account_once_ready (window, account, chat_id, is_chatroom);
 
-		if (empathy_account_chooser_is_ready (account_chooser))
-			account_chooser_ready_cb (account_chooser, window);
-		else
-			/* Chat will be selected once the account chooser is ready */
-			g_signal_connect (account_chooser, "ready",
-					  G_CALLBACK (account_chooser_ready_cb), window);
-	}
-
-	if (parent) {
+	if (parent != NULL) {
 		gtk_window_set_transient_for (GTK_WINDOW (window->window),
 					      GTK_WINDOW (parent));
 	}
@@ -324,6 +337,7 @@ log_window_destroy_cb (GtkWidget       *widget,
 {
 	g_free (window->last_find);
 	g_object_unref (window->log_manager);
+	tp_clear_object (&window->selected_account);
 	g_free (window->selected_chat_id);
 
 	g_free (window);
@@ -344,7 +358,7 @@ log_window_entry_find_changed_cb (GtkWidget       *entry,
 	is_sensitive &= !EMP_STR_EMPTY (str);
 	is_sensitive &=
 		!window->last_find ||
-		(window->last_find && strcmp (window->last_find, str) != 0);
+		(window->last_find && tp_strdiff (window->last_find, str));
 
 	gtk_widget_set_sensitive (window->button_find, is_sensitive);
 }
@@ -520,7 +534,7 @@ log_manager_searched_new_cb (GObject *manager,
 			hit = l->data;
 
 			/* Protect against invalid data (corrupt or old log files. */
-			if (!hit->account || !hit->chat_id) {
+			if (hit->account == NULL || hit->chat_id == NULL) {
 					continue;
 			}
 
@@ -551,7 +565,7 @@ log_manager_searched_new_cb (GObject *manager,
 			}
 	}
 
-	if (hits) {
+	if (hits != NULL) {
 			tpl_log_manager_search_free (hits);
 	}
 }
@@ -677,7 +691,7 @@ start_find_search (EmpathyLogWindow *window)
 	str = gtk_entry_get_text (GTK_ENTRY (window->entry_find));
 
 	/* Don't find the same crap again */
-	if (window->last_find && strcmp (window->last_find, str) == 0) {
+	if (window->last_find && !tp_strdiff (window->last_find, str)) {
 		return;
 	}
 
@@ -767,14 +781,13 @@ log_manager_got_chats_cb (GObject *manager,
 	EmpathyLogWindow      *window = user_data;
 	GList                 *chats;
 	GList                 *l;
-	EmpathyAccountChooser *account_chooser;
-	TpAccount             *account;
 	GtkTreeView           *view;
 	GtkTreeModel          *model;
 	GtkTreeSelection      *selection;
 	GtkListStore          *store;
 	GtkTreeIter            iter;
 	GError                *error = NULL;
+	gboolean               select_account = FALSE;
 
 	if (log_window == NULL)
 		return;
@@ -786,9 +799,6 @@ log_manager_got_chats_cb (GObject *manager,
 			return;
 	}
 
-	account_chooser = EMPATHY_ACCOUNT_CHOOSER (window->account_chooser_chats);
-	account = empathy_account_chooser_dup_account (account_chooser);
-
 	view = GTK_TREE_VIEW (window->treeview_chats);
 	model = gtk_tree_view_get_model (view);
 	selection = gtk_tree_view_get_selection (view);
@@ -799,15 +809,23 @@ log_manager_got_chats_cb (GObject *manager,
 
 			hit = l->data;
 
+			if (hit->account == NULL)
+				continue;
+
 			gtk_list_store_append (store, &iter);
 			gtk_list_store_set (store, &iter,
 					COL_CHAT_ICON, "empathy-available", /* FIXME */
 					COL_CHAT_NAME, hit->chat_id,
-					COL_CHAT_ACCOUNT, account,
+					COL_CHAT_ACCOUNT, hit->account,
 					COL_CHAT_ID, hit->chat_id,
 					COL_CHAT_IS_CHATROOM, hit->is_chatroom,
 					-1);
 
+			if (window->selected_account != NULL &&
+			    !tp_strdiff (tp_proxy_get_object_path (hit->account),
+			    tp_proxy_get_object_path (window->selected_account)))
+				select_account = TRUE;
+
 			/* FIXME: Update COL_CHAT_ICON/NAME */
 			if (hit->is_chatroom) {
 			} else {
@@ -820,7 +838,10 @@ log_manager_got_chats_cb (GObject *manager,
 			log_window_chats_changed_cb,
 			window);
 
-	g_object_unref (account);
+	/* We display the selected account if we populate the model with chats from
+	 * this account. */
+	if (select_account)
+		log_window_chats_set_selected (window);
 }
 
 static void
@@ -928,12 +949,8 @@ log_window_chats_accounts_changed_cb (GtkWidget       *combobox,
 }
 
 static void
-log_window_chats_set_selected  (EmpathyLogWindow *window,
-				TpAccount        *account,
-				const gchar     *chat_id,
-				gboolean         is_chatroom)
+log_window_chats_set_selected (EmpathyLogWindow *window)
 {
-	EmpathyAccountChooser *account_chooser;
 	GtkTreeView          *view;
 	GtkTreeModel         *model;
 	GtkTreeSelection     *selection;
@@ -941,9 +958,6 @@ log_window_chats_set_selected  (EmpathyLogWindow *window,
 	GtkTreePath          *path;
 	gboolean              ok;
 
-	account_chooser = EMPATHY_ACCOUNT_CHOOSER (window->account_chooser_chats);
-	empathy_account_chooser_set_account (account_chooser, account);
-
 	view = GTK_TREE_VIEW (window->treeview_chats);
 	model = gtk_tree_view_get_model (view);
 	selection = gtk_tree_view_get_selection (view);
@@ -963,9 +977,9 @@ log_window_chats_set_selected  (EmpathyLogWindow *window,
 				    COL_CHAT_IS_CHATROOM, &this_is_chatroom,
 				    -1);
 
-		if (this_account == account &&
-		    strcmp (this_chat_id, chat_id) == 0 &&
-		    this_is_chatroom == is_chatroom) {
+		if (this_account == window->selected_account &&
+		    !tp_strdiff (this_chat_id, window->selected_chat_id) &&
+		    this_is_chatroom == window->selected_is_chatroom) {
 			gtk_tree_selection_select_iter (selection, &iter);
 			path = gtk_tree_model_get_path (model, &iter);
 			gtk_tree_view_scroll_to_cell (view, path, NULL, TRUE, 0.5, 0.0);
@@ -978,6 +992,9 @@ log_window_chats_set_selected  (EmpathyLogWindow *window,
 		g_object_unref (this_account);
 		g_free (this_chat_id);
 	}
+
+	tp_clear_object (&window->selected_account);
+	tp_clear_pointer (&window->selected_chat_id, g_free);
 }
 
 static gboolean
@@ -1008,12 +1025,12 @@ log_window_chats_get_selected (EmpathyLogWindow  *window,
 			    COL_CHAT_IS_CHATROOM, &room,
 			    -1);
 
-	if (chat_id) {
+	if (chat_id != NULL) {
 		*chat_id = id;
 	} else {
 		g_free (id);
 	}
-	if (account) {
+	if (account != NULL) {
 		*account = acc;
 	} else {
 		g_object_unref (acc);
@@ -1091,6 +1108,9 @@ log_window_get_messages_for_date (EmpathyLogWindow *window,
       date,
       log_window_got_messages_for_date_cb,
       (gpointer) window);
+
+  g_free (chat_id);
+  g_object_unref (account);
 }
 
 static void
@@ -1163,7 +1183,7 @@ log_manager_got_dates_cb (GObject *manager,
       log_window_calendar_chats_day_selected_cb,
       window);
 
-  if (date) {
+  if (date != NULL) {
       /* Show messages of the most recent date */
       log_window_get_messages_for_date (window, date);
   }
@@ -1344,7 +1364,7 @@ log_window_entry_chats_changed_cb (GtkWidget       *entry,
 	str = gtk_entry_get_text (GTK_ENTRY (window->entry_chats));
 	empathy_chat_view_highlight (window->chatview_chats, str, FALSE);
 
-	if (str) {
+	if (str != NULL) {
 		empathy_chat_view_find_next (window->chatview_chats,
 					    str,
 					    TRUE,
@@ -1360,7 +1380,7 @@ log_window_entry_chats_activate_cb (GtkWidget       *entry,
 
 	str = gtk_entry_get_text (GTK_ENTRY (window->entry_chats));
 
-	if (str) {
+	if (str != NULL) {
 		empathy_chat_view_find_next (window->chatview_chats,
 					    str,
 					    FALSE,
