@@ -231,7 +231,9 @@ empathy_icon_name_for_individual (FolksIndividual *individual)
 	FolksPresenceType folks_presence;
 	TpConnectionPresenceType presence;
 
-	folks_presence = folks_individual_get_presence_type (individual);
+	folks_presence =
+	    folks_presence_owner_get_presence_type (
+	        FOLKS_PRESENCE_OWNER (individual));
 	presence = empathy_folks_presence_type_to_tp (folks_presence);
 
 	return empathy_icon_name_for_presence (presence);
@@ -564,7 +566,7 @@ avatar_file_load_contents_cb (GObject      *object,
 {
 	GFile *file = G_FILE (object);
 	PixbufAvatarFromIndividualClosure *closure = user_data;
-	char *data;
+	char *data = NULL;
 	gsize data_size;
 	struct SizeData size_data;
 	GError *error = NULL;
@@ -603,7 +605,7 @@ avatar_file_load_contents_cb (GObject      *object,
 	}
 
 	g_simple_async_result_set_op_res_gpointer (closure->result,
-			avatar_pixbuf_from_loader (loader), NULL);
+			avatar_pixbuf_from_loader (loader), g_object_unref);
 
 out:
 	g_simple_async_result_complete (closure->result);
@@ -617,9 +619,10 @@ out:
 void
 empathy_pixbuf_avatar_from_individual_scaled_async (
 		FolksIndividual     *individual,
-		GAsyncReadyCallback  callback,
 		gint                 width,
 		gint                 height,
+		GCancellable        *cancellable,
+		GAsyncReadyCallback  callback,
 		gpointer             user_data)
 {
 	GFile *avatar_file;
@@ -630,7 +633,8 @@ empathy_pixbuf_avatar_from_individual_scaled_async (
 			callback, user_data,
 			empathy_pixbuf_avatar_from_individual_scaled_async);
 
-	avatar_file = folks_avatar_get_avatar (FOLKS_AVATAR (individual));
+	avatar_file =
+		folks_avatar_owner_get_avatar (FOLKS_AVATAR_OWNER (individual));
 	if (avatar_file == NULL)
 		goto out;
 
@@ -639,7 +643,7 @@ empathy_pixbuf_avatar_from_individual_scaled_async (
 	if (closure == NULL)
 		goto out;
 
-	g_file_load_contents_async (avatar_file, NULL,
+	g_file_load_contents_async (avatar_file, cancellable,
 			avatar_file_load_contents_cb, closure);
 
 	g_object_unref (result);
@@ -652,6 +656,7 @@ out:
 	g_object_unref (result);
 }
 
+/* Return a ref on the GdkPixbuf */
 GdkPixbuf *
 empathy_pixbuf_avatar_from_individual_scaled_finish (
 		FolksIndividual *individual,
@@ -660,6 +665,7 @@ empathy_pixbuf_avatar_from_individual_scaled_finish (
 {
 	GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT (result);
 	gboolean result_valid;
+	GdkPixbuf *pixbuf;
 
 	g_return_val_if_fail (FOLKS_IS_INDIVIDUAL (individual), NULL);
 	g_return_val_if_fail (G_IS_SIMPLE_ASYNC_RESULT (simple), NULL);
@@ -672,7 +678,8 @@ empathy_pixbuf_avatar_from_individual_scaled_finish (
 			empathy_pixbuf_avatar_from_individual_scaled_async);
 	g_return_val_if_fail (result_valid, NULL);
 
-	return g_simple_async_result_get_op_res_gpointer (simple);
+	pixbuf = g_simple_async_result_get_op_res_gpointer (simple);
+	return pixbuf != NULL ? g_object_ref (pixbuf) : NULL;
 }
 
 GdkPixbuf *
@@ -1605,7 +1612,11 @@ empathy_window_present_with_time (GtkWindow *window,
 			gtk_widget_hide (GTK_WIDGET (window));
 	}
 
-	gtk_window_present_with_time (window, timestamp);
+	if (timestamp == GDK_CURRENT_TIME)
+		gtk_window_present (window);
+	else
+		gtk_window_present_with_time (window, timestamp);
+
 	gtk_window_set_skip_taskbar_hint (window, FALSE);
 	gtk_window_deiconify (window);
 }
@@ -1613,7 +1624,7 @@ empathy_window_present_with_time (GtkWindow *window,
 void
 empathy_window_present (GtkWindow *window)
 {
-  empathy_window_present_with_time (window, GDK_CURRENT_TIME);
+  empathy_window_present_with_time (window, gtk_get_current_event_time ());
 }
 
 GtkWindow *
