@@ -71,6 +71,12 @@
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyAccountsDialog)
 G_DEFINE_TYPE (EmpathyAccountsDialog, empathy_accounts_dialog, GTK_TYPE_DIALOG);
 
+enum
+{
+  NOTEBOOK_PAGE_ACCOUNT = 0,
+  NOTEBOOK_PAGE_LOADING
+};
+
 typedef struct {
   GtkWidget *alignment_settings;
   GtkWidget *alignment_infobar;
@@ -96,12 +102,22 @@ typedef struct {
   GtkWidget *label_type;
   GtkWidget *settings_widget;
 
-  /* We have to keep a reference on the actual EmpathyAccountWidget, not just
-   * his GtkWidget. It is the only reliable source we can query to know if
+  GtkWidget *notebook_account;
+  GtkWidget *spinner;
+  gboolean loading;
+
+  /* We have to keep a weak reference on the actual EmpathyAccountWidget, not
+   * just its GtkWidget. It is the only reliable source we can query to know if
    * there are any unsaved changes to the currently selected account. We can't
    * look at the account settings because it does not contain everything that
    * can be changed using the EmpathyAccountWidget. For instance, it does not
-   * contain the state of the "Enabled" checkbox. */
+   * contain the state of the "Enabled" checkbox.
+   *
+   * Even if we create it ourself, we just get a weak ref and not a strong one
+   * as EmpathyAccountWidget unrefs itself when the GtkWidget is destroyed.
+   * That's kinda ugly; cf bgo #640417.
+   *
+   * */
   EmpathyAccountWidget *setting_widget_object;
 
   gboolean  connecting_show;
@@ -310,7 +326,7 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
                 gchar *message;
 
                 message = g_strdup_printf (_("Offline — %s"),
-                    empathy_account_get_error_message (account));
+                    empathy_account_get_error_message (account, NULL));
                 gtk_info_bar_set_message_type (GTK_INFO_BAR (priv->infobar),
                     GTK_MESSAGE_WARNING);
 
@@ -322,7 +338,7 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
                 gchar *message;
 
                 message = g_strdup_printf (_("Disconnected — %s"),
-                    empathy_account_get_error_message (account));
+                    empathy_account_get_error_message (account, NULL));
                 gtk_info_bar_set_message_type (GTK_INFO_BAR (priv->infobar),
                     GTK_MESSAGE_ERROR);
 
@@ -475,9 +491,16 @@ account_dialog_create_settings_widget (EmpathyAccountsDialog *dialog,
   const gchar               *icon_name;
   TpAccount                 *account;
 
+  if (priv->setting_widget_object != NULL)
+    g_object_remove_weak_pointer (G_OBJECT (priv->setting_widget_object),
+        (gpointer *) &priv->setting_widget_object);
+
   priv->setting_widget_object =
       empathy_account_widget_new_for_protocol (settings, FALSE);
 
+  g_object_add_weak_pointer (G_OBJECT (priv->setting_widget_object),
+      (gpointer *) &priv->setting_widget_object);
+
   if (accounts_dialog_has_valid_accounts (dialog))
     empathy_account_widget_set_other_accounts_exist (
         priv->setting_widget_object, TRUE);
@@ -608,12 +631,17 @@ accounts_dialog_setup_ui_to_add_account (EmpathyAccountsDialog *dialog)
 
   if (is_gtalk)
     {
+      gchar *fallback_servers[] = {
+          "talkx.l.google.com",
+          "talkx.l.google.com:443,oldssl",
+          "talkx.l.google.com:80",
+          NULL};
+
       empathy_account_settings_set_icon_name_async (settings, "im-google-talk",
           NULL, NULL);
-      /* We should not have to set the server but that may cause issue with
-       * buggy router. */
-      empathy_account_settings_set_string (settings, "server",
-          "talk.google.com");
+
+      empathy_account_settings_set_strv (settings, "fallback-servers",
+          fallback_servers);
     }
   else if (is_facebook)
     {
@@ -1304,7 +1332,8 @@ accounts_dialog_model_selection_changed (GtkTreeSelection *selection,
     }
 
   /* Update remove button sensitivity */
-  gtk_widget_set_sensitive (priv->button_remove, is_selection && !creating);
+  gtk_widget_set_sensitive (priv->button_remove, is_selection && !creating &&
+      !priv->loading);
 }
 
 static void
@@ -1859,6 +1888,29 @@ accounts_dialog_set_selected_account (EmpathyAccountsDialog *dialog,
     gtk_tree_selection_select_iter (selection, &iter);
 }
 
+static void
+finished_loading (EmpathyAccountsDialog *self)
+{
+  EmpathyAccountsDialogPriv *priv = GET_PRIV (self);
+  GtkTreeSelection *selection;
+  gboolean has_selected;
+
+  priv->loading = FALSE;
+
+  gtk_widget_set_sensitive (priv->button_add, TRUE);
+  gtk_widget_set_sensitive (priv->button_import, TRUE);
+  gtk_widget_set_sensitive (priv->treeview, TRUE);
+
+  /* Sensitive the remove button if there is an account selected */
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
+  has_selected = gtk_tree_selection_get_selected (selection, NULL, NULL);
+  gtk_widget_set_sensitive (priv->button_remove, has_selected);
+
+  gtk_spinner_stop (GTK_SPINNER (priv->spinner));
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook_account),
+      NOTEBOOK_PAGE_ACCOUNT);
+}
+
 static void
 accounts_dialog_cms_prepare_cb (GObject *source,
     GAsyncResult *result,
@@ -1869,7 +1921,7 @@ accounts_dialog_cms_prepare_cb (GObject *source,
   EmpathyAccountsDialogPriv *priv = GET_PRIV (dialog);
 
   if (!empathy_connection_managers_prepare_finish (cms, result, NULL))
-    return;
+    goto out;
 
   accounts_dialog_update_settings (dialog, NULL);
 
@@ -1879,6 +1931,9 @@ accounts_dialog_cms_prepare_cb (GObject *source,
       g_object_unref (priv->initial_selection);
       priv->initial_selection = NULL;
     }
+
+out:
+  finished_loading (dialog);
 }
 
 static void
@@ -1985,6 +2040,7 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
   EmpathyAccountsDialogPriv    *priv = GET_PRIV (dialog);
   GtkWidget                    *content_area;
   GtkWidget *action_area, *vbox, *hbox, *align;
+  GtkWidget *alig;
 
   filename = empathy_file_lookup ("empathy-accounts-dialog.ui", "src");
 
@@ -1999,6 +2055,8 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
       "button_remove", &priv->button_remove,
       "button_import", &priv->button_import,
       "hbox_protocol", &priv->hbox_protocol,
+      "notebook_account", &priv->notebook_account,
+      "alignment_loading", &alig,
       NULL);
   g_free (filename);
 
@@ -2023,9 +2081,28 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
   gtk_widget_hide (priv->button_remove);
 #endif /* HAVE_MEEGO */
 
-  /* Remove button is unsensitive until we have a selected account */
+  /* Display loading page */
+  priv->loading = TRUE;
+
+  priv->spinner = gtk_spinner_new ();
+
+  gtk_spinner_start (GTK_SPINNER (priv->spinner));
+  gtk_widget_show (priv->spinner);
+
+  gtk_container_add (GTK_CONTAINER (alig), priv->spinner);
+
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook_account),
+      NOTEBOOK_PAGE_LOADING);
+
+  /* Remove button is insensitive until we have a selected account */
   gtk_widget_set_sensitive (priv->button_remove, FALSE);
 
+  /* Add and Import buttons and treeview are insensitive while the dialog
+   * is loading */
+  gtk_widget_set_sensitive (priv->button_add, FALSE);
+  gtk_widget_set_sensitive (priv->button_import, FALSE);
+  gtk_widget_set_sensitive (priv->treeview, FALSE);
+
   priv->combobox_protocol = empathy_protocol_chooser_new ();
   gtk_box_pack_start (GTK_BOX (priv->hbox_protocol), priv->combobox_protocol,
       TRUE, TRUE, 0);
@@ -2096,8 +2173,6 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
 
   gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
-  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-
   /* add dialog buttons */
   gtk_button_box_set_layout (GTK_BUTTON_BOX (action_area), GTK_BUTTONBOX_END);
 
