@@ -45,7 +45,6 @@
 #include "empathy-accounts-common.h"
 #include "empathy-accounts-dialog.h"
 #include "empathy-account-assistant.h"
-#include "empathy-import-mc4-accounts.h"
 #include "empathy-auto-salut-account-helper.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
@@ -88,25 +87,6 @@ maybe_show_accounts_ui (TpAccountManager *manager)
     empathy_accounts_show_accounts_ui (manager, NULL, gtk_main_quit);
 }
 
-static void
-cm_manager_prepared_cb (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  if (!empathy_connection_managers_prepare_finish (
-      EMPATHY_CONNECTION_MANAGERS (source), result, NULL))
-    {
-      g_warning ("Failed to prepare connection managers singleton");
-      gtk_main_quit ();
-      return;
-    }
-
-  empathy_accounts_import (TP_ACCOUNT_MANAGER (user_data),
-    EMPATHY_CONNECTION_MANAGERS (source));
-
-  maybe_show_accounts_ui (TP_ACCOUNT_MANAGER (user_data));
-}
-
 static void
 account_manager_ready_for_accounts_cb (GObject *source_object,
     GAsyncResult *result,
@@ -151,18 +131,7 @@ account_manager_ready_for_accounts_cb (GObject *source_object,
     }
   else
     {
-      if (empathy_import_mc4_has_imported ())
-        {
-          maybe_show_accounts_ui (manager);
-        }
-      else
-        {
-          EmpathyConnectionManagers *cm_mgr =
-            empathy_connection_managers_dup_singleton ();
-
-          empathy_connection_managers_prepare_async (
-            cm_mgr, cm_manager_prepared_cb, manager);
-        }
+      maybe_show_accounts_ui (manager);
     }
 }
 
@@ -214,7 +183,7 @@ main (int argc, char *argv[])
         NULL },
       { "if-needed", 'n',
         0, G_OPTION_ARG_NONE, &only_if_needed,
-        N_("Don't display any dialogs if there are any non-salut accounts"),
+        N_("Don't display any dialogs if there are any non-Salut accounts"),
         NULL },
       { "select-account", 's',
         G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING, &selected_account_name,
@@ -253,10 +222,12 @@ main (int argc, char *argv[])
 
   if (unique_app_is_running (unique_app))
     {
-      unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
-
-      g_object_unref (unique_app);
-      return EXIT_SUCCESS;
+      if (unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL) ==
+          UNIQUE_RESPONSE_OK)
+        {
+          g_object_unref (unique_app);
+          return EXIT_SUCCESS;
+        }
     }
 
   account_manager = tp_account_manager_dup ();
