@@ -1300,7 +1300,7 @@ chat_window_show_or_update_notification (EmpathyChatWindow *window,
 		   to an existing notification with the same title.
 		   In this way the previous message will not be lost: the new
 		   message will appear below it, in the same notification */
-		notification = notify_notification_new (header, escaped, NULL, NULL);
+		notification = notify_notification_new (header, escaped, NULL);
 
 		if (priv->notification == NULL) {
 			priv->notification = notification;
@@ -1351,6 +1351,7 @@ chat_window_set_highlight_room_tab_label (EmpathyChat *chat)
 static void
 chat_window_new_message_cb (EmpathyChat       *chat,
 			    EmpathyMessage    *message,
+			    gboolean pending,
 			    EmpathyChatWindow *window)
 {
 	EmpathyChatWindowPriv *priv;
@@ -1425,11 +1426,16 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 
 		empathy_sound_play (GTK_WIDGET (priv->dialog),
 		    EMPATHY_SOUND_MESSAGE_INCOMING);
-		chat_window_show_or_update_notification (window, message, chat);
+
+		/* Pending messages have already been displayed in the approver, so we don't
+		* display a notification for those. */
+		if (!pending)
+			chat_window_show_or_update_notification (window, message, chat);
 	}
 
-	/* update the number of unread messages */
+	/* update the number of unread messages and the window icon */
 	chat_window_title_update (priv);
+	chat_window_icon_update (priv);
 }
 
 static GtkNotebook *
@@ -1453,8 +1459,8 @@ chat_window_detach_hook (GtkNotebook *source,
 
 	empathy_chat_window_move_chat (window, new_window, chat);
 
-	gtk_window_move (GTK_WINDOW (priv->dialog), x, y);
 	gtk_widget_show (priv->dialog);
+	gtk_window_move (GTK_WINDOW (priv->dialog), x, y);
 
 	return NULL;
 }
