@@ -206,8 +206,8 @@ status_icon_update_notification (EmpathyStatusIcon *icon)
 			   to an existing notification with the same title.
 			   In this way the previous message will not be lost: the new
 			   message will appear below it, in the same notification */
-			notification = notify_notification_new_with_status_icon
-				(priv->event->header, message_esc, NULL, priv->icon);
+			notification = notify_notification_new
+				(priv->event->header, message_esc, NULL);
 
 			if (priv->notification == NULL) {
 				priv->notification = notification;
@@ -330,10 +330,14 @@ status_icon_event_added_cb (EmpathyEventManager *manager,
 		return;
 	}
 
+	if (event->type == EMPATHY_EVENT_TYPE_AUTH) {
+		return;
+	}
+
 	DEBUG ("New event %p", event);
 
 	priv->event = event;
-	if (event->must_ack) {
+	if (event->must_ack || event->type == EMPATHY_EVENT_TYPE_AUTH) {
 		priv->showing_event_icon = TRUE;
 		status_icon_update_icon (icon);
 		status_icon_update_tooltip (icon);
@@ -358,6 +362,10 @@ status_icon_event_removed_cb (EmpathyEventManager *manager,
 		return;
 	}
 
+	if (event->type == EMPATHY_EVENT_TYPE_AUTH) {
+		return;
+	}
+
 	priv->event = empathy_event_manager_get_top_event (priv->event_manager);
 
 	status_icon_update_tooltip (icon);
@@ -385,6 +393,10 @@ status_icon_event_updated_cb (EmpathyEventManager *manager,
 		return;
 	}
 
+	if (event->type == EMPATHY_EVENT_TYPE_AUTH) {
+		return;
+	}
+
 	if (empathy_notify_manager_notification_is_enabled (priv->notify_mgr)) {
 		status_icon_update_notification (icon);
 	}
